@@ -69,5 +69,18 @@ class FastTrackerConfiger:
         env_dict = os.environ
         for key, val in env_dict.items():
             if key.startswith("FastTracker_"):
-                config_name = functions.lower_case_name(key[12:])
-                setattr(config, config_name, val)
+                if key.startswith("FastTracker_TenantCodeReader_"):
+                    args = {functions.lower_case_name(key[29:]): val}
+                    config.set_tenant_code_reader(**args)
+                elif key.startswith("FastTracker_UserCodeReader_"):
+                    args = {functions.lower_case_name(key[27:]): val}
+                    config.set_user_code_reader(**args)
+                elif key.startswith("FastTracker_EnvCodeReader_"):
+                    args = {functions.lower_case_name(key[26:]): val}
+                    config.set_env_code_reader(**args)
+                elif key.startswith("FastTracker_CarrierHeader_"):
+                    args = {functions.lower_case_name(key[26:]): val}
+                    config.set_carrier_header(**args)
+                else:
+                    config_name = functions.lower_case_name(key[12:])
+                    setattr(config, config_name, val)
